/*
 * File : phActive.C
 *
 * Description : This file contains the method definitions
 *	for the phActive class.
 */

#include "phActive.h"
#include "phInactive.h"
#include "phlayer.h"

/*
 * Function : PhDataReq 
 *
 * Description : This method handles a PH_DataReq
 *	primitive. It invokes DataRequest on the phlayer
 *	object, with _pktToSend as the argument.
 */

phStateMachine *
phActive::PhDataReq(int &errorCode)
{
	if (_ph->DataRequest(_ph->_pktToSend) == 0 ) 
		errorCode = codeSuccessful;
	else
		errorCode = codeGeneralFailure;
	return this;
}

/*
 * Function : PhDeactivateReq 
 *
 * Description : This method handles a PH_DeactivateReq
 *	primitive. It transmits the PH_DEACTIVATE character
 *	on the xmit FIFO. Closes the FIFOs.
 */
phStateMachine *
phActive::PhDeactivateReq(int &errorCode)
{
	_ph->SendCommand(PH_DEACTIVATE);
	_ph->CloseLink();
	errorCode = codeSuccessful;
	delete this;
	return new phInactive(_ph);
}

/*
 * Function : PhData
 *
 * Description : This function handles the case when
 *	a data packet is received on the recv. FIFO. It
 *  invokes PH_DataInd primitive on the data-link 
 *	layer.
 */

phStateMachine *
phActive::PhData(int &errorCode)
{
	layer *dl = _ph->GetNPlus1Layer();
	if ( dl )
		dl->Command(PH_DataInd,errorCode,_ph->_lastRecdPkt);
	else
		errorCode = codeGeneralFailure;
	return this;
}

/*
 * Function : PhDeactivate
 *
 * Description : This function handles the case when
 *	a PH_DEACTIVATE character is received on the recv. FIFO.
 *	It sends a PH_DeactivateInd primitive to the data-link
 *	layer.
 */

phStateMachine *
phActive::PhDeactivate(int &errorCode)
{
	layer *dl = _ph->GetNPlus1Layer();
	if (dl )
		dl->Command(PH_DeactivateInd,errorCode);
	_ph->CloseLink();
	delete this;
	return new phInactive(_ph);
}

/*
 * Function : PrintState
 *
 * Description : Prints the state.
 */

void 
phActive::PrintState() 
{
	TRACE(phSmModule,2,("State Active\n"));
}

